@@ -9,6 +9,12 @@ from sphinx.util.compat import Directive
 from sphinx.util.compat import make_admonition
 from subprocess import call
 import os
+from PIL import Image
+
+try:
+    from IPython import embed
+except ImportError, e:
+    pass
 
 
 class UMLGenerateDirective(Directive):
@@ -30,7 +36,13 @@ class UMLGenerateDirective(Directive):
         basename = os.path.basename(module_path).split(".")[0]
         print call(['pyreverse', '-o', 'png', '-p', basename, os.path.abspath(os.path.join(SRC_DIR, module_path))])
         uri = directives.uri(os.path.join(DIR_NAME, "classes_{0}.png".format(basename)))
-        img = nodes.image(uri=uri)
+        i = Image.open(os.path.join(SRC_DIR, uri))
+        scale = 100
+        max_width = 1000
+        image_width = i.size[0]
+        if image_width > max_width:
+            scale = max_width * scale / image_width 
+        img = nodes.image(uri=uri, scale=scale)
         os.chdir(SRC_DIR)
         return [img]
 
